==> dde-control-center_5.5.88.orig.tar.xz: dde-control-center-5.5.88/translations/recovery_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="65"/>
        <source>Rolling back the system, please wait...</source>
        <translation>Sistemi po kthehet prapa, ju lutemi, prisni…</translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="266"/>
        <source>Rollback failed.</source>
        <translation>Kthimi prapa dështoi.</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="271"/>
        <source>Reboot</source>
        <translation>Rinisu</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="280"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Jeni i sigurt se doni të kthehet prapa te %1, kopjeruajtur më %2?</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="283"/>
        <source>Cancel and Reboot</source>
        <translation>Anuloje dhe Rinisu</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="284"/>
        <source>Confirm</source>
        <translation>Ripohojeni</translation>
    </message>
</context>
</TS>

==> dde-control-center_5.5.149.orig.tar.xz: dde-control-center-5.5.149/translations/recovery_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="33"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <source>Rolling back the system, please wait...</source>
        <translation>Sistemi po kthehet prapa, ju lutemi, prisni…</translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="250"/>
        <source>Rollback failed.</source>
        <translation>Kthimi prapa dështoi.</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="255"/>
        <source>Reboot</source>
        <translation>Rinisu</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="264"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Jeni i sigurt se doni të kthehet mbrapsht te %1 kopjeruajtur më %2?</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="267"/>
        <source>Cancel and Reboot</source>
        <translation>Anuloje dhe Rinisu</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="268"/>
        <source>Confirm</source>
        <translation>Ripohojeni</translation>
    </message>
</context>
</TS>
